@@ -308,8 +308,12 @@ def pytest_configure(config):
 
 @pytest.hookimpl(tryfirst=True)
 def pytest_configure(config):
-    filename = 'report_' + datetime.now().strftime(
-        "%Y%m%d_%H%M%S") + '_' + config.known_args_namespace.keyword + ".html"  # report_YYYYMMDD_HHMMSS_[target].html
+    if config.option.logicapp is not "":
+        filename = 'report_' + config.option.logicapp + '_' + datetime.now().strftime(
+            "%Y%m%d_%H%M%S") + '_' + config.known_args_namespace.keyword + ".html"  # report_[logicapp]_YYYYMMDD_HHMMSS_[target].html
+    else:
+        filename = 'report_' + datetime.now().strftime(
+            "%Y%m%d_%H%M%S") + '_' + config.known_args_namespace.keyword + ".html"  # report_YYYYMMDD_HHMMSS_[target].html
     path = os.path.join(config.rootdir, 'reports', filename)
     global report_path
     global report_name
@@ -468,6 +472,14 @@ def pytest_addoption(parser):
                          dest="wdm",
                          default='N',
                          help="Determine user want to use Web driver Manager or not: Y or N")
+        parser.addoption("--logicapp",
+                         dest="logicapp",
+                         default='',
+                         help="Provide the logic app name which will affect the report name")
+        parser.addoption("--post_logicapp",
+                         dest="post_logicapp",
+                         default='N',
+                         help="Provide the logic app key in config to call the logicapp app trigger email report. Default N. Input Y if needed")
 
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
@@ -1029,3 +1041,21 @@ def screenshot_option(request):
         print("Python says:%s" % str(e))
 
     return setup
+
+
+@pytest.fixture(scope='session')
+def logicapp(request):
+    try:
+        return request.config.getoption("--logicapp")
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
+
+@pytest.fixture(scope='session')
+def post_logicapp(request):
+    try:
+        return request.config.getoption("--post_logicapp")
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
